package es.uca.xmleye.xpath;

/*
  Copyright (C) 2005-2008 Antonio García Domínguez
  
  This program is free software; you can redistribute it 
  and/or modify it under the terms of the GNU General Public 
  License as published by the Free Software Foundation; 
  either version 2 of the License, or (at your option) any 
  later version.
  
  This program is distributed in the hope that it will be 
  useful, but WITHOUT ANY WARRANTY; without even the implied 
  warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
  PURPOSE. See the GNU General Public License for more 
  details.
  
  You should have received a copy of the GNU General Public 
  License along with this program; if not, write to the Free 
  Software Foundation, Inc., 59 Temple Place, Suite 330, 
  Boston, MA 02111-1307 USA
*/

import java.util.*;

import es.uca.xmleye.xpath.WholeWordMatchXPathFunction;
import junit.framework.*;
import junit.textui.*;

/** 
    Tests de unidad de las extensiones XPath.
*/
public class XPathExtensionsTest extends TestCase 
{

  /** Crea una nueva colección de pruebas. */
  public XPathExtensionsTest(String nombre) 
  {
    super(nombre);
  }

  /** Crea el conjunto de casos de prueba a ejecutar mediante JUnit. */
  public static Test suite() 
  {
    return new TestSuite(XPathExtensionsTest.class);
  }

  /** Lanza las pruebas definidas por esta clase mediante JUnit. */
  public static void main(String[] args) 
  {
    TestRunner.run(suite());
  }

  /** Prueba el funcionamiento correcto de la extensión de palabras completas. */
  public void testPalabraCompleta() {
    WholeWordMatchXPathFunction func = new WholeWordMatchXPathFunction();

    assertTrue((Boolean)func.evaluate(listaPar("itty meenie moe", "meenie")));
    assertTrue((Boolean)func.evaluate(listaPar("itty meenie moe", "itty")));
    assertTrue((Boolean)func.evaluate(listaPar("itty meenie moe", "moe")));
    assertTrue((Boolean)func.evaluate(listaPar("-itty", "-itty")));
    assertTrue((Boolean)func.evaluate(listaPar(":executable-counterpart", "executable-counterpart")));
    assertTrue((Boolean)func.evaluate(listaPar(":executable-counterpart", ":executable-counterpart")));
    assertFalse((Boolean)func.evaluate(listaPar("::executable-counterpart", ":executable-counterpart")));
    assertFalse((Boolean)func.evaluate(listaPar("itty", "itt")));
    assertFalse((Boolean)func.evaluate(listaPar("itty", "tt")));
    assertFalse((Boolean)func.evaluate(listaPar("itty", "tty")));
    assertFalse((Boolean)func.evaluate(listaPar(" itty meenie moe", "itt")));
    assertFalse((Boolean)func.evaluate(listaPar("itty meenie moe", "y m")));
    assertFalse((Boolean)func.evaluate(listaPar("itty meenie moe", "nie")));
    assertFalse((Boolean)func.evaluate(listaPar("itty meenie moe", "oe")));

    // Caracteres a escapar
    assertTrue((Boolean)func.evaluate(listaPar("  abaca\\dra ba  ", "abaca\\dra")));
    assertTrue((Boolean)func.evaluate(listaPar("  abaca\\dra\\E ba", "abaca\\dra\\E")));
    assertTrue((Boolean)func.evaluate(listaPar("abacadra\\  ", "abacadra\\")));

    // Multilínea
    assertTrue((Boolean)func.evaluate(listaPar("(LOCAL (DEFUN TRIPLE-REV (X)\n          (REV3 X)))",
					       "LOCAL")));

    // Texto o claves vacíos
    assertFalse((Boolean)func.evaluate(listaPar("", ":executable-counterpart")));
    assertTrue((Boolean)func.evaluate(listaPar(":executable-counterpart", "")));

  }

  /** Prepara los recursos comunes necesarios para las pruebas. */
  @Override
protected void setUp() {}

  /** Prepara los recursos comunes necesarios para las pruebas. */
  @Override
protected void tearDown() {}

  /** Crea una lista con dos objetos. 
      @param a Primer objeto.
      @param b Segundo objeto.
      @return Lista con dos objetos: a y b. */
  private List<Object> listaPar(Object a, Object b) {
    List<Object> lista = new ArrayList<Object>();
    lista.add(a);
    lista.add(b);
    return lista;
  }

}
